"""Command-line interface for ReportMonster."""

import argparse
import importlib
import sys

from reportmonster.config.config import MonsterConfig
from reportmonster.reports import get_available_reports


def run_report(args):
    """Run a specified report."""
    config = MonsterConfig(args.config)
    try:
        module_name = f"reportmonster.reports.{args.report}"
        try:
            # Try to import from installed package first
            module = importlib.import_module(module_name)
        except ImportError:
            # If not found, try custom report path
            if args.report_path:
                sys.path.insert(0, args.report_path)
                module = importlib.import_module(args.report)
            else:
                raise

        # Initialize report
        if hasattr(module, "run"):
            module.run(config, args)
        else:
            print(f"Error: Report {args.report} does not have a run function")
    except ImportError as e:
        print(f"Error: Could not import {args.report}: {str(e)}")


def list_reports(args):
    """List available reports."""
    reports = get_available_reports()
    if not reports:
        print("No reports available.")
        return

    print("Available reports:")
    for report in reports:
        print(f"  - {report}")


def main():
    """Main entry point for the ReportMonster CLI."""
    parser = argparse.ArgumentParser(
        description="ReportMonster - Moodle Reporting Tool"
    )
    parser.add_argument(
        "--config",
        "-c",
        type=str,
        default="settings.ini",
        help="Path to configuration file (default: settings.ini)",
    )

    subparsers = parser.add_subparsers(dest="command", help="Command to execute")

    # Run report command
    run_parser = subparsers.add_parser("run", help="Run a report")
    run_parser.add_argument("report", type=str, help="Name of the report to execute")
    run_parser.add_argument(
        "--report-path", type=str, help="Path to custom reports directory"
    )
    run_parser.set_defaults(func=run_report)

    # List reports command
    list_parser = subparsers.add_parser("list", help="List available reports")
    list_parser.set_defaults(func=list_reports)

    args = parser.parse_args()

    if not hasattr(args, "func"):
        parser.print_help()
        return

    args.func(args)


if __name__ == "__main__":
    main()
